summaryrefslogtreecommitdiff
path: root/mpi/mpi-scan.c
diff options
context:
space:
mode:
authorWerner Koch <wk@gnupg.org>1999-02-16 13:16:30 +0000
committerWerner Koch <wk@gnupg.org>1999-02-16 13:16:30 +0000
commit788077d888e7b95448ed8c1a84d7e5d6b9244d9f (patch)
tree413375191713a0e35c0f60b9c6bb669327060057 /mpi/mpi-scan.c
parentf5a7426be64684b9eaa6b2c1506374b3efc88aca (diff)
downloadlibgcrypt-788077d888e7b95448ed8c1a84d7e5d6b9244d9f.tar.gz
See ChangeLog: Tue Feb 16 14:10:02 CET 1999 Werner Koch
Diffstat (limited to 'mpi/mpi-scan.c')
-rw-r--r--mpi/mpi-scan.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/mpi/mpi-scan.c b/mpi/mpi-scan.c
index 82ac7262..ea5673f4 100644
--- a/mpi/mpi-scan.c
+++ b/mpi/mpi-scan.c
@@ -32,7 +32,7 @@
* FIXME: This code is VERY ugly!
*/
int
-mpi_getbyte( MPI a, unsigned index )
+mpi_getbyte( MPI a, unsigned idx )
{
int i, j;
unsigned n;
@@ -43,7 +43,7 @@ mpi_getbyte( MPI a, unsigned index )
for(n=0,i=0; i < a->nlimbs; i++ ) {
limb = ap[i];
for( j=0; j < BYTES_PER_MPI_LIMB; j++, n++ )
- if( n == index )
+ if( n == idx )
return (limb >> j*8) & 0xff;
}
return -1;
@@ -51,10 +51,10 @@ mpi_getbyte( MPI a, unsigned index )
/****************
* Put a value at position INDEX into A. index counts from lsb to msb
*/
void
-mpi_putbyte( MPI a, unsigned index, int xc )
+mpi_putbyte( MPI a, unsigned idx, int xc )
{
int i, j;
unsigned n;
@@ -66,7 +66,7 @@ mpi_putbyte( MPI a, unsigned index, int xc )
for(n=0,i=0; i < a->alloced; i++ ) {
limb = ap[i];
for( j=0; j < BYTES_PER_MPI_LIMB; j++, n++ )
- if( n == index ) {
+ if( n == idx ) {
#if BYTES_PER_MPI_LIMB == 4
if( j == 0 )
limb = (limb & 0xffffff00) | c;
@@ -51,10 +51,10 @@ mpi_getbyte( MPI a, unsigned index )
/****************
- * Put a value at position INDEX into A. index counts from lsb to msb
+ * Put a value at position IDX into A. idx counts from lsb to msb
*/
void